# -*- mode: python; coding: utf-8 -*-
# Copyright (C) 2017-2019 by BDE ENS Paris-Saclay
# SPDX-License-Identifier: GPL-3.0-or-later

from cas import views as cas_views
from django.contrib.auth.decorators import login_required
from django.contrib.auth.views import PasswordResetView
from django.urls import include, path
from django.views.generic import RedirectView, TemplateView
from rest_framework import routers

import media.views
import users.views
from .admin import admin_site

# API router
router = routers.DefaultRouter()
router.register(r'authors', media.views.AuteurViewSet)
router.register(r'media', media.views.MediaViewSet)
router.register(r'borrowed_items', media.views.EmpruntViewSet)
router.register(r'games', media.views.JeuViewSet)
router.register(r'users', users.views.UserViewSet)
router.register(r'groups', users.views.GroupViewSet)

urlpatterns = [
    path('', media.views.index, name='index'),

    # Include project routers
    path('users/', include('users.urls')),
    path('media/', include('media.urls')),
    path('logs/', include('logs.urls')),

    # REST API
    path('api/', include(router.urls)),
    path('api-auth/', include('rest_framework.urls')),

    # Include Django Contrib and Core routers
    path('accounts/password_reset/', PasswordResetView.as_view(),
         name='admin_password_reset'),
    path('i18n/', include('django.conf.urls.i18n')),
    path('accounts/', include('django.contrib.auth.urls')),
    path('accounts/profile/', RedirectView.as_view(pattern_name='index')),
    path('database/doc/', include('django.contrib.admindocs.urls')),
    path('database/', admin_site.urls),

    # Include CAS authentication
    # TODO Uncomment when NK20 will be ready
    # path('admin/login/', cas_views.login, name='login'),
    # path('admin/logout/', cas_views.logout, name='logout'),
]
